%%%this script is used to analyze the azimuthal dependence of a set of RIXS
%%%spectra at a certain q. Please first define which dataset is used by
%%%changing the folder directory. For example, if the dataset of UD sample
%%%at q = (0.28, 0.28) is used, change the filepath to 'UD_0p28_0p28'.

%%%please change the current folder to the folder where this script locates.
clear rixs_sigma rixs_pi

[parentdir,~,~]=fileparts(pwd);
filepath = strcat(parentdir, '\OD2_0p33_0\');%change it for other samples and q

if contains(filepath, '0p28_0p28')
    wt = 50;%wt is the wedge angle of the sample holder
elseif contains(filepath, '0p23_0p23') || contains(filepath, '0p33_0')
    wt = 40;
elseif contains(filepath, '0p13_0p13') || contains(filepath, '0p18_0')
    wt = 20;
else
    wt = 10;
end

%% read data
%%%%rixs data have three column, the first one is the energy loss, the
%%%%second is the photon counts, which is the total photon counts measured
%%%%by 3 CCD chips and with a typically total time of 15 minuts, but here
%%%%the counts are normalized to 5 minutes and 1 CCD. The third one is the
%%%%statistic errors
phi_sigma = importdata(strcat(filepath, 'phi_sigma.txt'));
phi_pi = importdata(strcat(filepath, 'phi_pi.txt'));
len1 = length(phi_sigma);
len2 = length(phi_pi);
for ii = 1:len1
    fn = strcat('d', num2str(ii));
    filen = strcat(filepath, 'rixs_phi_', num2str(phi_sigma(ii)), '_sigma.txt');
    data = importdata(filen, ' ', 1);
    rixs_sigma.(fn) = data.data;
end

for ii = 1:len2
    fn = strcat('d', num2str(ii));
    filen = strcat(filepath, 'rixs_phi_', num2str(phi_pi(ii)), '_pi.txt');
    data = importdata(filen, ' ', 1);
    rixs_pi.(fn) = data.data;
end

%% bin two nearest pixels and convert into matrices
%%%%%get the low-energy spectra in (-0.9, 0.4) eV%%%%%%%
Esp=-0.9;%energy loss start point
Eep=0.4;%energy endpoint;

fnames=fieldnames(rixs_sigma);
nf=length(fnames);
for ii=1:nf
    dtemp = rixs_sigma.(fnames{ii});
    dtemp1 = dtemp(((dtemp(:,1)>=Esp) & (dtemp(:,1)<=Eep)), :);
    temp1 = movmean(dtemp1(:, 1:2),2,1);
    err1 = sqrt(movmean(dtemp1(:,3).^2, 2, 1).*2)./2;
    if ii == 1
        eloss = temp1(2:2:end, 1);
        len = length(eloss);
        AI_sigma = zeros(len, nf);
        err_sigma = zeros(len, nf);
    end
    AI_sigma(:, ii) = temp1(2:2:end, 2);
    err_sigma(:, ii) = err1(2:2:end);
end

fnames=fieldnames(rixs_pi);
nf=length(fnames);
for ii=1:nf
    dtemp = rixs_pi.(fnames{ii});
    dtemp1 = dtemp(((dtemp(:,1)>=Esp) & (dtemp(:,1)<=Eep)), :);
    temp1 = movmean(dtemp1(:, 1:2),2,1);
    err1 = sqrt(movmean(dtemp1(:,3).^2, 2, 1).*2)./2;
    if ii == 1
        eloss = temp1(2:2:end, 1);
        len = length(eloss);
        AI_pi = zeros(len, nf);
        err_pi = zeros(len, nf);
    end
    AI_pi(:, ii) = temp1(2:2:end, 2);
    err_pi(:, ii) =err1(2:2:end);
end
%% include errors caused by the uncertainty in determining zero energy loss positions
%%%%%%here we set the error of the energy loss values to be 10% of the
%%%%%%hwhm of the resolution function
%%%%%%this x error is then converted into the y error of rixs photon intensity
hwhm = 0.05;% the hwhm of the resolution function
epp = 0.0081*2;% the energy difference bewteen two nearest data pionts, times 2 is due to the binning in 
               % above section
len1 = size(AI_sigma, 2);
aa = zeros(1, len1);
dif1 =[aa; diff(AI_sigma, 1, 1)];%differential of the rixs of sigma polarization
len2 = size(AI_pi, 2);
aa = zeros(1, len2);
dif2 =[aa; diff(AI_pi, 1, 1)];
xerr = 0.1*hwhm/epp;%the error in x variable--energy loss
x2yerr1 = dif1.*xerr;
x2yerr2 = dif2.*xerr;
terr_sigma = sqrt(err_sigma.^2+x2yerr1.^2);
terr_pi = sqrt(err_pi.^2+x2yerr2.^2);
%% save results
%dlmwrite(strcat(filepath, 'AI_sigma.txt'),AI_sigma);
%dlmwrite(strcat(filepath, 'AI_pi.txt'),AI_pi);
%dlmwrite(strcat(filepath, 'terr_sigma.txt'),terr_sigma);
%dlmwrite(strcat(filepath, 'terr_pi.txt'),terr_pi);
%dlmwrite(strcat(filepath, 'eloss_for_map.txt'),eloss);
%% seprate charge and magnetic excitations
fac = importdata(strcat(parentdir, '\absorption_coeff\faa_fcc.txt'));%load absorption coefficents faa and fcc
%%%the first column is the energy, second and third the faa and fcc for UD
%%%sample, fourth and fifth for OD1 and sixth and seventh for OD2.
pp = 2; %using the absorption tensor elements of the OD1 sample
Els=fac(:,1)-932.93;
faa1=fac(:,1+2*pp-1);
fcc1=fac(:,2+2*pp-1);
muin1=interp1(Els, faa1, 0, 'pchip');%the value of absorption coefficient at L3 resonance and phi = 0

[Ic1sim, Ic2sim, Im1sim, Im2sim] = azi_dep(wt, phi_sigma', phi_pi', eloss, fac, pp);
[wcv, wmv, errc, errm] = spin_charge_decomp(AI_sigma, AI_pi, terr_sigma,...
    terr_pi, Ic1sim, Ic2sim, Im1sim, Im2sim, 1);

%[Ievsim, Iehsim, Imvsim, Imhsim] = azi_dep(wt, phi_sigma', phi_pi', eloss, fac, pp);
%[wcv2, wmv2, errc2, errm2] = spin_charge_decomp(AIb1, AIb2, err1, err2, Ievsim,...
%    Iehsim, Imvsim, Imhsim, 1);
%% systematic errors on wedge angle
%%% the wedge angle of the sample holder will also provide some systematic
%%% error, here we estimate this error of wedge angle is 1 degree.
%%%%%wt-1%%%%%%
[Ic1sim1, Ic2sim1, Im1sim1, Im2sim1] = azi_dep(wt-1, phi_sigma', phi_pi', eloss, fac, pp);
[wcv1, wmv1, errc1, errm1] = spin_charge_decomp(AI_sigma, AI_pi, terr_sigma,...
    terr_pi, Ic1sim1, Ic2sim1, Im1sim1, Im2sim1, 1);

%%%%%wt+1%%%%%%
[Ic1sim2, Ic2sim2, Im1sim2, Im2sim2] = azi_dep(wt+1, phi_sigma', phi_pi', eloss, fac, pp);
[wcv2, wmv2, errc2, errm2] = spin_charge_decomp(AI_sigma, AI_pi, terr_sigma,...
    terr_pi, Ic1sim2, Ic2sim2, Im1sim2, Im2sim2, 1);
%%%% the estimated total errors%%%%%%
terrc = sqrt(errc.^2 + (wcv2-wcv1).^2./4);
terrm = sqrt(errm.^2 + (wmv2-wmv1).^2./4);
%% check fitting
ex=-0.3;
scdcomp_check(eloss, AI_sigma, AI_pi, terr_sigma, terr_pi, ex,...
    Ic1sim, Ic2sim, Im1sim, Im2sim, wcv, wmv, phi_sigma, phi_pi);
%% plot the weights
sw_charg=wcv.*4./muin1;%normalized by incident abosorption coefficient.
                       %4 is due to the non-uinty scattering matrix of charge scattering
sw_spin=wmv./muin1;
cherr=terrc.*4./muin1;
sperr=terrm./muin1;
figure;
errorbar(eloss, sw_charg, cherr, 'ro', 'linewidth', 1);
hold on
errorbar(eloss, sw_spin, sperr, 'go', 'linewidth', 1);
hold off
xlabel('E ( eV )','FontSize',16);
ylabel('Intensity','FontSize',16);
legend('charge', 'spin');
set(gca,'fontsize',16);
set(gcf, 'color', 'white');
%% save results
fileID = fopen(strcat(filepath, 'sw_charge.txt'),'w');
fprintf(fileID,'%6s %8s %8s\r\n','Eloss','weight','err');
fprintf(fileID,'%2.4f %4.4f %4.4f\r\n', [eloss wcv terrc]');
fclose(fileID);
fileID = fopen(strcat(filepath, 'sw_spin.txt'),'w');
fprintf(fileID,'%6s %8s %8s\r\n','Eloss','weight','err');
fprintf(fileID,'%2.4f %4.4f %4.4f\r\n', [eloss wmv terrm]');
fclose(fileID);

fileID = fopen(strcat(filepath, 'sw_charge_norm.txt'),'w');
fprintf(fileID,'%6s %8s %8s\r\n','Eloss','weight','err');
fprintf(fileID,'%2.4f %4.4f %4.4f\r\n', [eloss sw_charg cherr]');
fclose(fileID);
fileID = fopen(strcat(filepath, 'sw_spin_norm.txt'),'w');
fprintf(fileID,'%6s %8s %8s\r\n','Eloss','weight','err');
fprintf(fileID,'%2.4f %4.4f %4.4f\r\n', [eloss sw_spin sperr]');
fclose(fileID);