function [Ic1sim, Ic2sim, Im1sim, Im2sim] = azi_dep(wt, phi_sigma, phi_pi, Erange, fac, pp)
%%this function is used to simulate the azimuthal dependence of the spin
%%and charge excitations, the self-absorption is included, where the
%%values of pp specify from which sample the absorption coefficents are used 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%pp=1 for ud sample, 2 for od1 3 for od2
Elsv=fac(:,1)-932.93;
Elsh=fac(:,1)-932.93;
faa1=fac(:,1+2*pp-1);
fcc1=fac(:,2+2*pp-1);

syms x;
Rtot=[cosd(wt)*cos(x/180*pi), -cosd(wt)*sin(x/180*pi), -sind(wt); sin(x/180*pi), cos(x/180*pi), 0;...
    sind(wt)*cos(x/180*pi), -sind(wt)*sin(x/180*pi), cosd(wt)];
%symbolic expression of the rotation matrix
ei1=[0; 1; 0]; %sigam in
ei2=[0.9063; 0; 0.4226]; %pi in
ef2=[0.9063; 0; -0.4226]; %pi out
ef1=[0; 1; 0]; %sigma out
kin=[-0.4226, 0, 0.9063];
kout=[-0.4226, 0, -0.9063];
%nsam=[0.6428;0;0.7660];%normal vector of sample surface
nsam=[sind(wt)*cos(x/180*pi); -sind(wt)*sin(x/180*pi); cosd(wt)];
Ff_el=[2, 0, 0; 0, 2, 0; 0, 0, 0];
Ff_mg=[0, 1i, 0; -1i, 0, 0; 0, 0, 0];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

syms faa fcc;
F_sa=[faa, 0, 0; 0, faa, 0; 0, 0, fcc];
muinv=ei1.'*transpose(Rtot)*F_sa*Rtot*ei1;
muinh=ei2.'*transpose(Rtot)*F_sa*Rtot*ei2;
muoutv=ef1.'*transpose(Rtot)*F_sa*Rtot*ef1;
muouth=ef2.'*transpose(Rtot)*F_sa*Rtot*ef2;
faainv=interp1(Elsv, faa1, 0, 'pchip');%Ein is fixed at Ei = 0
fccinv=interp1(Elsv, fcc1, 0, 'pchip');
faainh=interp1(Elsv, faa1, 0, 'pchip');%Ein is fixed at Ei
fccinh=interp1(Elsv, fcc1, 0, 'pchip');

muinv1=subs(muinv, {faa, fcc}, {faainv, fccinv});
muinh1=subs(muinh, {faa, fcc}, {faainh, fccinh});
muoutv1=subs(muoutv, {faa, fcc}, {faa1, fcc1});
muouth1=subs(muouth, {faa, fcc}, {faa1, fcc1});

Cvvs=1./(muinv1+muoutv1*(-kin*nsam)/(kout*nsam));%self-absorption for sigma to sigma, symbolic expression
Cvhs=1./(muinv1+muouth1*(-kin*nsam)/(kout*nsam));
Chvs=1./(muinh1+muoutv1*(-kin*nsam)/(kout*nsam));
Chhs=1./(muinh1+muouth1*(-kin*nsam)/(kout*nsam));

Cvv=double(subs(Cvvs, phi_sigma));%self-absorption factors as a function of both phi and energy, matix.
Cvh=double(subs(Cvhs, phi_sigma));
Chv=double(subs(Chvs, phi_pi));
Chh=double(subs(Chhs, phi_pi));

Evv=ef1.'*transpose(Rtot)*Ff_el*Rtot*ei1;%elastic transition matrix for sigma to sigma, sympolic expression
Evh=ef2.'*transpose(Rtot)*Ff_el*Rtot*ei1;
Ehv=ef1.'*transpose(Rtot)*Ff_el*Rtot*ei2;
Ehh=ef2.'*transpose(Rtot)*Ff_el*Rtot*ei2;

Ivv_el=abs(double(subs(Evv, phi_sigma))).^2;%
Ivh_el=abs(double(subs(Evh, phi_sigma))).^2;
Ihv_el=abs(double(subs(Ehv, phi_pi))).^2;
Ihh_el=abs(double(subs(Ehh, phi_pi))).^2;

Mvv=ef1.'*transpose(Rtot)*Ff_mg*Rtot*ei1;%magnetic transition matrix for sigma to sigma, sympolic expression
Mvh=ef2.'*transpose(Rtot)*Ff_mg*Rtot*ei1;
Mhv=ef1.'*transpose(Rtot)*Ff_mg*Rtot*ei2;
Mhh=ef2.'*transpose(Rtot)*Ff_mg*Rtot*ei2;

Ivv_mg=abs(double(subs(Mvv, phi_sigma))).^2;
Ivh_mg=abs(double(subs(Mvh, phi_sigma))).^2;
Ihv_mg=abs(double(subs(Mhv, phi_pi))).^2;
Ihh_mg=abs(double(subs(Mhh, phi_pi))).^2;

n1=size(Cvv,1);
m1=size(Cvv,2);
m2=size(Chh,2);
ICvin_el=zeros(n1,m1);
IChin_el=zeros(n1,m2);
ICvin_mg=zeros(n1,m1);
IChin_mg=zeros(n1,m2);
for ii=1:n1
    ICvin_el(ii,:)=Ivv_el.*Cvv(ii,:)+Ivh_el.*Cvh(ii,:);
    IChin_el(ii,:)=Ihv_el.*Chv(ii,:)+Ihh_el.*Chh(ii,:);
    ICvin_mg(ii,:)=Ivv_mg.*Cvv(ii,:)+Ivh_mg.*Cvh(ii,:);
    IChin_mg(ii,:)=Ihv_mg.*Chv(ii,:)+Ihh_mg.*Chh(ii,:);
end
nep = size(Erange, 1);
Ic1sim=zeros(nep,m1);%charge excitation at sigma polarization
Ic2sim=zeros(nep,m2);%charge, pi
Im1sim=zeros(nep,m1);%spin, sigma
Im2sim=zeros(nep,m2);
for ii=1:m1
    Ic1sim(:,ii)=interp1(Elsv, ICvin_el(:,ii), Erange, 'pchip');
    Im1sim(:,ii)=interp1(Elsv, ICvin_mg(:,ii), Erange, 'pchip');
end
for ii=1:m2
    Ic2sim(:,ii)=interp1(Elsh, IChin_el(:,ii), Erange, 'pchip');
    Im2sim(:,ii)=interp1(Elsh, IChin_mg(:,ii), Erange, 'pchip');
end